package com.ozs.base.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.ozs.base.domain.BaseExpert;
import com.ozs.base.domain.BaseUnitInformation;
import com.ozs.base.domain.vo.BaseExpertVo;
import com.ozs.base.mapper.BaseExpertMapper;
import com.ozs.base.service.BaseExpertService;
import com.ozs.common.core.domain.AjaxResult;
import com.ozs.common.utils.StringUtils;
import com.ozs.plan.doman.PlanQuarter;
import com.ozs.plan.doman.ProvisionalPlan;
import com.ozs.pm.doman.PmDemand;
import com.ozs.pm.doman.PmDemandExpertRef;
import com.ozs.pm.service.IPmDemandService;
import com.ozs.pm.service.PmDemandExpertRefService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.ObjectUtils;

import java.util.Date;
import java.util.List;

@Service
public class BaseExpertServiceImpl extends ServiceImpl<BaseExpertMapper, BaseExpert> implements BaseExpertService {

    @Autowired
    private BaseExpertMapper baseExpertMapper;
    @Autowired
    private PmDemandExpertRefService pmDemandExpertRefService;
    @Autowired
    private IPmDemandService pmDemandService;

    @Override
    public int insertExpert(BaseExpert baseExpert) {
        // base_unit_information 单位信息表
        if(StringUtils.isNotNull(baseExpert.getUnitInformation())) {
            List<BaseUnitInformation> baseUnitInformationList = baseExpertMapper.selectByUnitInformation(baseExpert.getUnitInformation());
            if (baseUnitInformationList.size() <= 0) {
                BaseUnitInformation baseUnitInformation = new BaseUnitInformation();
                baseUnitInformation.setUnitName(baseExpert.getUnitInformation());
                baseUnitInformation.setCreated(baseExpert.getExpertName());
                baseUnitInformation.setCreateTime(new Date());
                Integer i = baseExpertMapper.insertBaseUnitInformation(baseUnitInformation);
            }
        }

        return baseExpertMapper.insertExpert(baseExpert);
    }

    @Override
    public int updateSupplierType(BaseExpert baseExpert) {
        LambdaUpdateWrapper<BaseExpert> lambdaUpdateWrapper = new LambdaUpdateWrapper<>();
        //eq是指你查询的条件，set是指你修改的值
        lambdaUpdateWrapper
                .eq(BaseExpert::getId, baseExpert.getId())
                .set(BaseExpert::getStatus, baseExpert.getStatus());
        return baseExpertMapper.update(null, lambdaUpdateWrapper);
    }

    @Override
    public AjaxResult selectReviewProject(BaseExpertVo baseExpertVo) {
        // 通过专家ID查询 与专家库关联的采购执行管理ID
        List<Integer> demandIdList = pmDemandExpertRefService.selectByExpertId(baseExpertVo.getId());
        if (StringUtils.isNull(demandIdList) && demandIdList.size() <=0) {
            return AjaxResult.error("当前专家还有有被抽取！");
        }
        List<PmDemand> pmDemandList = pmDemandService.selectByDemandIdList(demandIdList);
        PageHelper.startPage(baseExpertVo.getPageNum().intValue(), baseExpertVo.getPageSize().intValue());
        PageInfo<PmDemand> pageInfo = new PageInfo<>(pmDemandList);
        return AjaxResult.success(pageInfo);
    }
}
